FlameInterstitialAd class

Constructors

FlameInterstitialAd()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

destroy() Future<void>
销毁
isLoading() Future<bool>
是否加载中
isReady() Future<bool>
是否准备好
load({required String placementId, OnAdLoaded? onAdLoaded, OnAdLoadFailed? onAdLoadFailed, OnAdShow? onAdShow, OnAdClicked? onAdClicked, OnAdClosed? onAdClosed}) → void
加载广告
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
show() Future<void>
展示
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited