FlameNativeDrawAd class

Constructors

FlameNativeDrawAd()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

destroy() Future<void>
销毁
dispose() → void
isLoading() Future<bool>
是否加载中
isReady() Future<bool>
广告是否准备就绪
load({required String placementId, required int adViewWidth, required int adViewHeight, OnAdLoaded? onAdLoaded, OnAdLoadFailed? onAdLoadFailed, OnAdShow? onAdShow, OnAdShowFailed? onAdShowFailed, OnAdClicked? onAdClicked}) → void
加载原生 Draw 广告
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove() Future<void>
移除广告
show() Future<void>
展示广告
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited